# Based on Joaquin Aldas & Ezequiel Uriel
# Analisis Multivariante con R (2nd Ed.)
# Ed. alfacentauro, 2017.

library(psych)
library(rela)
library(paran)
library(ggplot2)

Y <- read.table("usability.csv", header=TRUE, sep=";")

# Not consider User, User Profile and Date
user_date <- c(1, 2, 3, 36)
X <- Y[,-user_date]

# Number of questions and instances
p <- length(colnames(X))
n <- length(X[,1])

# Correlation matrix
R <- cor(X, use="complete.obs", method="pearson")

# Measures of adjustment or sampling adequacy
(kmo <- KMO(R))

# Sphericity of the correlation matrix
cortest.bartlett(R, n=n)

# Determinant of the correlation matrix
det(R)

# Internal consistency of the items
# Cronbach's alpha with 95% confidence interval
ia.R <- itemanal(R)
ia.R$Alpha
ia.R$Conf.Alpha

# Determination of the number of factors
windows()
paran(X, iterations=5000, graph=TRUE, color=FALSE) 

# EFA estimation of main axes
fit.pa <- fa(X, nfactors=4, fm="pa", rotate="varimax", scores="regression")
fa.sort(fit.pa)
print(fit.pa)

windows()
plot(fit.pa) 

windows()
fa.diagram(fit.pa)

# Residual matrix and the statistic obtained from it
fit.pa$residual
fit.pa$rms

# Perceptual map
graphic.data <- data.frame(fit.pa$scores,Y[, c(2,3)])

#                        PA1  PA2  PA3  PA4
# Proportion Explained  0.37 0.27 0.20 0.15

# The first factor (PA1) is related to Visual Design, 
# the second factor (PA2) with Interaction, 
# the third factor (PA3) with Information Design, 
# and the fourth factor (PA4) with Satisfaction. 


# Averages of the variables that make up each factor by type
aggregate(
  cbind(
    P01,
    P02,
    P03,
    P04,
    P05,
    P06,
    P07,
    P08,
    P09,
    P10,
    P11,
    P12,
    P13,
    P14,
    P15,
    P16,
    P17,
    P18,
    P19,
    P20,
    P21,
    P22,
    P23,
    P24,
    P25,
    P26,
    P27,
    P28,
    P29,
    P30,
    P31,
    P32
  ) ~ Gender,
  data = Y,
  mean,
  na.rm = TRUE
)
aggregate(
  cbind(
    P01,
    P02,
    P03,
    P04,
    P05,
    P06,
    P07,
    P08,
    P09,
    P10,
    P11,
    P12,
    P13,
    P14,
    P15,
    P16,
    P17,
    P18,
    P19,
    P20,
    P21,
    P22,
    P23,
    P24,
    P25,
    P26,
    P27,
    P28,
    P29,
    P30,
    P31,
    P32
  ) ~ Alone,
  data = Y,
  mean,
  na.rm = TRUE
)

aggregate(cbind(
  PA1 = ((
    P21 + P19 + P26 + P25 + P24 + P09 + P20 + P23 + P22 + P18 + P06 + P17
  ) / 12),
  PA2 = ((
    P05 + P10 + P03 + P01 + P16 + P13 + P02 + P14 + P07 + P08
  ) / 10),
  PA3 = ((P11 + P28 + P12 + P04 + P27 + P15) / 6),
  PA4 = ((P30 + P29 + P31 + P32) / 4)
) ~ Gender,
data = Y,
mean,
na.rm = TRUE)

aggregate(cbind(
  PA1 = ((
    P21 + P19 + P26 + P25 + P24 + P09 + P20 + P23 + P22 + P18 + P06 + P17
  ) / 12),
  PA2 = ((
    P05 + P10 + P03 + P01 + P16 + P13 + P02 + P14 + P07 + P08
  ) / 10),
  PA3 = ((P11 + P28 + P12 + P04 + P27 + P15) / 6),
  PA4 = ((P30 + P29 + P31 + P32) / 4)
) ~ Alone,
data = Y,
mean,
na.rm = TRUE)

# Variable Gender
# PA2 VS PA3
windows()
ggplot(graphic.data)+
  geom_point(aes(x=PA2, y=PA3,color=graphic.data$Gender,
                 shape=graphic.data$Gender),size=3)+
  geom_vline(xintercept = 0,colour="darkgray")+
  geom_hline(yintercept = 0,colour="darkgray")+
  labs (x="PA2. Interaction (27%)", y="PA3. Information Design (20%)")+
  theme(legend.title=element_blank())

# Variable Alone
# PA3 VS PA4
windows()
ggplot(graphic.data)+
  geom_point(aes(x=PA3, y=PA4,color=graphic.data$Alone,
                 shape=graphic.data$Alone),size=3)+
  geom_vline(xintercept = 0,colour="darkgray")+
  geom_hline(yintercept = 0,colour="darkgray")+
  labs (x="PA3. Information Design (20%)", y="PA4. Satisfaction (15%)")+
  theme(legend.title=element_blank())

